### Konfigurace plaginu v Lua souboru

Některé pluginy pro svůj chod potřebují na konfigurovat. Tyto konfigurace se provádějí v jazyce [Lua](https://www.lua.org/). Většinou bývá pravidlem že konfiguraci najdete na GitHubu u jednotlivých pluginů, mi ji jen musíme zkopírovat či případně upravit dle svých preferencí a uložit do souborů kde máme Neovim.

Máme dvě možnosti jak takovou konfiguraci uložit. Buď do souboru `init.vim` nebo pro lepší přehlednost do souboru lua kde bude mít každý plugin svůj soubor.

##### První způsob:

Toto je jednoduší způsob konfigurace jejím přidání do 'init.vim'.

1. V souboru 'init.vim' vytvoříme tyto dvě značky:

````lua
lua << EOF


EOF
````

2. A mezi ně vložíme samotný config, například takto:

````lua
lua << EOF
-- nvim-lightbulb setup
require('nvim-lightbulb').setup({
  autocmd = { enabled = true },
})
EOF
````

A dále podsebe přidáváme jednotlivé značky 'lua << EOF' 'EOF' a do nich vklkádat konfigurace.

##### Druhý způsob:

Tnto způsob je o trochu složitější, ale pomůže lépe organizovat konfigurační soubory a mít lepší přehled.

1. do souboru 'init.vim' přidáme tento řádek:

````lua
lua require('kankys') 
````
Tím jsme si naimprtovali soubor do kterého budeme importovat jednotlivé konfigurace.

2. Ve složce Neovim kde máme soubor 'init.vim' vytvoříme složku 'lua'.

3. Ve složce 'lua' vytvoříme složku s váším nickem nebo jak se vám zlíbí. V mém případě jsem zvolil 'kankys'.

Měli by jste teď mít tutu strukturu: '~/.config/nvim/lua/kankys/'

4. Ve složce 'kankys' vytvoříme soubor:

````
init.lua
````
Do něj budeme importovat jednotlivé konfigurace.

5. Vytvoříme se soubor s názvem pluginu s koncovkou lua  kterého chceme konfigurovat.

Já budu chtít například konfigurovat plugin 'gitsings'.

6. Vytvoříme ve složce 'kankys' soubor 'gitsings.lua'. Do něj vlažíme konfiguraci dle návodu z Githubu u pluginu.

Soubor pak bude vypadat takto:

````lua
require('gitsigns').setup {
    -- signs config
    current_line_blame = true,
    current_line_blame_opts = {
        virt_text_pos = 'right_align'
    }
}
````
A uložíme ho.

7. Poslení bod na importovat konfiguraci do 'init.lua'

Otevřeme soubor 'init.lua' a do něj vložíme:

````
require('kankys/gitsigns')
````

A soubor uložíme.

Takto budeme přidávat další importy do 'init.lua'.

<div style="text-align: center;">
  Copyright © 2024 - 2025 🚀 ApolloNvim / Lukáš Kaňka
</div>
